var app = angular.module('launchpad', ['oauth3.org', 'ui.router', 'LocalStorageModule']);

app.config(['$stateProvider', '$urlRouterProvider', 'localStorageServiceProvider',
  function ($stateProvider, $urlRouterProvider, localStorageServiceProvider) {

  localStorageServiceProvider.setPrefix('launchpad').setStorageType('sessionStorage');

  $urlRouterProvider.otherwise('/splash-page');
  $stateProvider
  .state('splash-page', {
    data: { requiresLogin: false },
    url: '/splash-page',
    templateUrl: '/templates/splash-page.html',
  })
  .state('app',{
    data: { requiresLogin: true },
    url: '/',
    views: {
      'header': {
        templateUrl: '/templates/partials/header.html',
        controller: 'loginCtrl',
        controllerAs: 'vm'
      },
      'menu': {
        templateUrl: '/templates/partials/menu.html'
      },
      'content': {
        templateUrl: '/templates/home.html'
      }
    }
  })
  .state('app.home', {
    url: 'home',
    views: {
      'content@': {
        templateUrl: 'templates/home.html',
        controller: 'loginCtrl',
        controllerAs: 'vm'
      }
    }
  })
  .state('app.bolt', {
    url: 'bolt',
    views: {
      'content@': {
        templateUrl: 'templates/bolt.html',
        controller: 'boltCtrl',
        controllerAs: 'vm'
      }
    }
  })
  .state('app.files', {
    url: 'files',
    views: {
      'content@': {
        templateUrl: 'templates/files.html',
        controller: 'fileCtrl',
        controllerAs: 'vm'
      }
    }
  })
  .state('app.contacts', {
    url: 'contacts',
    views: {
      'content@': {
        templateUrl: 'templates/contacts.html',
        controller: 'contactCtrl',
        controllerAs: 'vm'
      }
    }
  })
  .state('app.music', {
    url: 'music',
    views: {
      'content@': {
        templateUrl: 'templates/music.html',
        controller: 'musicCtrl',
        controllerAs: 'vm'
      }
    }
  })
  .state('app.email', {
    url: 'email',
    views: {
      'content@': {
        templateUrl: 'templates/email.html',
        controller: 'emailCtrl',
        controllerAs: 'vm'
      }
    }
  })
  .state('app.website', {
    url: 'website',
    views: {
      'content@': {
        templateUrl: 'templates/website.html',
        controller: 'websiteCtrl',
        controllerAs: 'vm'
      }
    }
  })
  .state('app.dns', {
    url: 'dns',
    views: {
      'content@': {
        templateUrl: 'templates/dns.html',
        controller: 'dnsCtrl',
        controllerAs: 'vm'
      }
    }
  })
  .state('app.account-settings', {
    url: 'account-settings',
    views: {
      'content@': {
        templateUrl: 'templates/account-settings.html',
        controller: 'loginCtrl',
        controllerAs: 'vm'
      }
    }
  });
}]);

app.run(['$rootScope', '$state', 'Auth', function($rootScope, $state, Auth) {
  $rootScope.urlArray = [];

  $rootScope.$on('$stateChangeStart', function(event, toState, toParams, fromState, fromParams) {
    var requiresLogin = toState.data.requiresLogin;
    $rootScope.redirectedURL = toState.url;
    $rootScope.urlArray.push($rootScope.redirectedURL);
    if ($rootScope.urlArray.length > 1) {
      $rootScope.redirectedURL = $rootScope.urlArray[0];
      $rootScope.urlArray = [];
    }

    if (requiresLogin && !Auth.isLoggedIn()) {
      event.preventDefault();
      $state.go('splash-page', { 'toState': toState.name });
    }
  });
}]);
